PAULE
=====

.. image:: https://zenodo.org/badge/355606517.svg
   :target: https://zenodo.org/badge/latestdoi/355606517

Predictive Articulatory speech synthesis Utilizing Lexical Embeddings (PAULE) a
python frame work to plan control parameter trajectories for the VocalTractLab
simulator for a target acoustics or semantic embedding.

Acknowledgements
----------------
This research was supported by an ERC advanced Grant (no. 742545) and the University of Tübingen.
